From 1c9ccce5209cd1727bf80e632f4f781c651e0c35 Mon Sep 17 00:00:00 2001
From: InsanityAutomation
 <38436470+InsanityAutomation@users.noreply.github.com>
Date: Tue, 24 Dec 2019 01:03:08 -0500
Subject: [PATCH] Add NOZZLE_AS_PROBE (no probe offsets) (#15929)

---
 Marlin/Configuration.h                                   | 6 ++++++
 Marlin/src/core/utility.cpp                              | 2 ++
 Marlin/src/gcode/bedlevel/abl/G29.cpp                    | 9 +++++----
 Marlin/src/inc/Conditionals_LCD.h                        | 2 +-
 Marlin/src/inc/Conditionals_post.h                       | 4 ++++
 Marlin/src/inc/SanityCheck.h                             | 7 ++++---
 Marlin/src/module/probe.cpp                              | 2 +-
 Marlin/src/module/probe.h                                | 8 ++++++++
 buildroot/share/tests/LPC1768-tests                      | 2 +-
 config/default/Configuration.h                           | 6 ++++++
 config/examples/3DFabXYZ/Migbot/Configuration.h          | 6 ++++++
 config/examples/ADIMLab/Gantry v1/Configuration.h        | 6 ++++++
 config/examples/ADIMLab/Gantry v2/Configuration.h        | 6 ++++++
 config/examples/AlephObjects/TAZ4/Configuration.h        | 6 ++++++
 config/examples/Alfawise/U20-bltouch/Configuration.h     | 6 ++++++
 config/examples/Alfawise/U20/Configuration.h             | 6 ++++++
 config/examples/AliExpress/CL-260/Configuration.h        | 6 ++++++
 config/examples/AliExpress/UM2pExt/Configuration.h       | 6 ++++++
 config/examples/Anet/A2/Configuration.h                  | 6 ++++++
 config/examples/Anet/A2plus/Configuration.h              | 6 ++++++
 config/examples/Anet/A6/Configuration.h                  | 6 ++++++
 config/examples/Anet/A8/Configuration.h                  | 6 ++++++
 config/examples/Anet/A8plus/Configuration.h              | 6 ++++++
 config/examples/Anet/E16/Configuration.h                 | 6 ++++++
 config/examples/AnyCubic/i3/Configuration.h              | 6 ++++++
 config/examples/ArmEd/Configuration.h                    | 6 ++++++
 config/examples/Azteeg/X5GT/Configuration.h              | 6 ++++++
 config/examples/BIBO/TouchX/cyclops/Configuration.h      | 6 ++++++
 config/examples/BIBO/TouchX/default/Configuration.h      | 6 ++++++
 config/examples/BQ/Hephestos/Configuration.h             | 6 ++++++
 config/examples/BQ/Hephestos_2/Configuration.h           | 6 ++++++
 config/examples/BQ/WITBOX/Configuration.h                | 6 ++++++
 .../examples/BigTreeTech/SKR Mini E3 1.0/Configuration.h | 6 ++++++
 .../examples/BigTreeTech/SKR Mini E3 1.2/Configuration.h | 6 ++++++
 config/examples/Cartesio/Configuration.h                 | 6 ++++++
 config/examples/Creality/CR-10/Configuration.h           | 6 ++++++
 config/examples/Creality/CR-10S/Configuration.h          | 6 ++++++
 config/examples/Creality/CR-10_5S/Configuration.h        | 6 ++++++
 config/examples/Creality/CR-10mini/Configuration.h       | 6 ++++++
 config/examples/Creality/CR-20 Pro/Configuration.h       | 6 ++++++
 config/examples/Creality/CR-20/Configuration.h           | 6 ++++++
 config/examples/Creality/CR-8/Configuration.h            | 6 ++++++
 config/examples/Creality/Ender-2/Configuration.h         | 6 ++++++
 config/examples/Creality/Ender-3/Configuration.h         | 6 ++++++
 config/examples/Creality/Ender-4/Configuration.h         | 6 ++++++
 config/examples/Creality/Ender-5/Configuration.h         | 6 ++++++
 config/examples/Dagoma/Disco Ultimate/Configuration.h    | 6 ++++++
 .../EVNOVO (Artillery)/Sidewinder X1/Configuration.h     | 6 ++++++
 .../EXP3D/Imprimante multifonction/Configuration.h       | 6 ++++++
 config/examples/Einstart-S/Configuration.h               | 6 ++++++
 config/examples/FYSETC/AIO_II/Configuration.h            | 6 ++++++
 .../examples/FYSETC/Cheetah 1.2/BLTouch/Configuration.h  | 6 ++++++
 config/examples/FYSETC/Cheetah 1.2/base/Configuration.h  | 6 ++++++
 config/examples/FYSETC/Cheetah/BLTouch/Configuration.h   | 6 ++++++
 config/examples/FYSETC/Cheetah/base/Configuration.h      | 6 ++++++
 config/examples/FYSETC/F6_13/Configuration.h             | 6 ++++++
 config/examples/FYSETC/S6/Configuration.h                | 6 ++++++
 config/examples/Felix/DUAL/Configuration.h               | 6 ++++++
 config/examples/Felix/Single/Configuration.h             | 6 ++++++
 config/examples/FlashForge/CreatorPro/Configuration.h    | 6 ++++++
 config/examples/FolgerTech/i3-2020/Configuration.h       | 6 ++++++
 config/examples/Formbot/Raptor/Configuration.h           | 6 ++++++
 config/examples/Formbot/T_Rex_2+/Configuration.h         | 6 ++++++
 config/examples/Formbot/T_Rex_3/Configuration.h          | 6 ++++++
 config/examples/Geeetech/A10/Configuration.h             | 6 ++++++
 config/examples/Geeetech/A10D/Configuration.h            | 6 ++++++
 config/examples/Geeetech/A10M/Configuration.h            | 6 ++++++
 config/examples/Geeetech/A10T/Configuration.h            | 6 ++++++
 config/examples/Geeetech/A20/Configuration.h             | 6 ++++++
 config/examples/Geeetech/A20M/Configuration.h            | 6 ++++++
 config/examples/Geeetech/A20T/Configuration.h            | 6 ++++++
 config/examples/Geeetech/A30/Configuration.h             | 6 ++++++
 config/examples/Geeetech/E180/Configuration.h            | 6 ++++++
 config/examples/Geeetech/GT2560/Configuration.h          | 6 ++++++
 config/examples/Geeetech/I3_Pro_X-GT2560/Configuration.h | 6 ++++++
 config/examples/Geeetech/MeCreator2/Configuration.h      | 6 ++++++
 config/examples/Geeetech/PI3A PRO/Configuration.h        | 6 ++++++
 .../Geeetech/Prusa i3 Pro B/bltouch/Configuration.h      | 6 ++++++
 .../Geeetech/Prusa i3 Pro B/noprobe/Configuration.h      | 6 ++++++
 config/examples/Geeetech/Prusa i3 Pro C/Configuration.h  | 6 ++++++
 config/examples/Geeetech/Prusa i3 Pro W/Configuration.h  | 6 ++++++
 config/examples/HMS434/Configuration.h                   | 6 ++++++
 config/examples/Infitary/i3-M508/Configuration.h         | 6 ++++++
 config/examples/JGAurora/A1/Configuration.h              | 6 ++++++
 config/examples/JGAurora/A5/Configuration.h              | 6 ++++++
 config/examples/JGAurora/A5S/Configuration.h             | 6 ++++++
 config/examples/MakerParts/Configuration.h               | 6 ++++++
 config/examples/Malyan/M150/Configuration.h              | 6 ++++++
 config/examples/Malyan/M200/Configuration.h              | 6 ++++++
 config/examples/Micromake/C1/basic/Configuration.h       | 6 ++++++
 config/examples/Micromake/C1/enhanced/Configuration.h    | 6 ++++++
 config/examples/Mks/Robin/Configuration.h                | 6 ++++++
 config/examples/Mks/Robin_Lite3/Configuration.h          | 6 ++++++
 config/examples/Mks/Robin_Pro/Configuration.h            | 6 ++++++
 config/examples/Mks/Sbase/Configuration.h                | 6 ++++++
 config/examples/Modix/Big60/Configuration.h              | 6 ++++++
 config/examples/Printrbot/PrintrboardG2/Configuration.h  | 6 ++++++
 config/examples/RapideLite/RL200/Configuration.h         | 6 ++++++
 config/examples/Renkforce/RF100/Configuration.h          | 6 ++++++
 config/examples/Renkforce/RF100XL/Configuration.h        | 6 ++++++
 config/examples/Renkforce/RF100v2/Configuration.h        | 6 ++++++
 config/examples/RepRapPro/Huxley/Configuration.h         | 6 ++++++
 config/examples/RepRapWorld/Megatronics/Configuration.h  | 6 ++++++
 config/examples/RigidBot/Configuration.h                 | 6 ++++++
 config/examples/SCARA/MP_SCARA/Configuration.h           | 6 ++++++
 config/examples/SCARA/Morgan/Configuration.h             | 6 ++++++
 .../examples/STM32/Black_STM32F407VET6/Configuration.h   | 6 ++++++
 config/examples/STM32/STM32F103RE/Configuration.h        | 6 ++++++
 config/examples/STM32/STM32F4/Configuration.h            | 6 ++++++
 config/examples/STM32/stm32f103ret6/Configuration.h      | 6 ++++++
 config/examples/Sanguinololu/Configuration.h             | 6 ++++++
 config/examples/Tevo/Michelangelo/Configuration.h        | 6 ++++++
 config/examples/Tevo/Tarantula Pro/Configuration.h       | 6 ++++++
 .../examples/Tevo/Tornado/V1 (MKS Base)/Configuration.h  | 6 ++++++
 .../examples/Tevo/Tornado/V2 (MKS GEN-L)/Configuration.h | 6 ++++++
 config/examples/TheBorg/Configuration.h                  | 6 ++++++
 config/examples/TinyBoy2/Configuration.h                 | 6 ++++++
 config/examples/Tronxy/X1/Configuration.h                | 6 ++++++
 config/examples/Tronxy/X3A/Configuration.h               | 6 ++++++
 config/examples/Tronxy/X5S-2E/Configuration.h            | 6 ++++++
 config/examples/Tronxy/X5S/Configuration.h               | 6 ++++++
 config/examples/Tronxy/XY100/Configuration.h             | 6 ++++++
 config/examples/UltiMachine/Archim1/Configuration.h      | 6 ++++++
 config/examples/UltiMachine/Archim2/Configuration.h      | 6 ++++++
 config/examples/VORONDesign/Configuration.h              | 6 ++++++
 config/examples/Velleman/K8200/Configuration.h           | 6 ++++++
 config/examples/Velleman/K8400/Dual-head/Configuration.h | 6 ++++++
 .../examples/Velleman/K8400/Single-head/Configuration.h  | 6 ++++++
 config/examples/WASP/PowerWASP/Configuration.h           | 6 ++++++
 config/examples/Wanhao/Duplicator 6/Configuration.h      | 6 ++++++
 config/examples/Wanhao/Duplicator i3 2.1/Configuration.h | 6 ++++++
 .../examples/Wanhao/Duplicator i3 Mini/Configuration.h   | 6 ++++++
 config/examples/adafruit/ST7565/Configuration.h          | 6 ++++++
 .../examples/delta/Dreammaker/Overlord/Configuration.h   | 6 ++++++
 .../delta/Dreammaker/Overlord_Pro/Configuration.h        | 6 ++++++
 config/examples/delta/FLSUN/QQ-S/Configuration.h         | 6 ++++++
 .../examples/delta/FLSUN/auto_calibrate/Configuration.h  | 6 ++++++
 config/examples/delta/FLSUN/kossel/Configuration.h       | 6 ++++++
 config/examples/delta/FLSUN/kossel_mini/Configuration.h  | 6 ++++++
 .../examples/delta/Geeetech/Rostock 301/Configuration.h  | 6 ++++++
 config/examples/delta/Hatchbox_Alpha/Configuration.h     | 6 ++++++
 config/examples/delta/MKS/SBASE/Configuration.h          | 6 ++++++
 .../examples/delta/Tevo Little Monster/Configuration.h   | 6 ++++++
 config/examples/delta/generic/Configuration.h            | 6 ++++++
 config/examples/delta/kossel_mini/Configuration.h        | 6 ++++++
 config/examples/delta/kossel_pro/Configuration.h         | 6 ++++++
 config/examples/delta/kossel_xl/Configuration.h          | 6 ++++++
 config/examples/gCreate/gMax1.5+/Configuration.h         | 6 ++++++
 config/examples/makibox/Configuration.h                  | 6 ++++++
 config/examples/tvrrug/Round2/Configuration.h            | 6 ++++++
 config/examples/wt150/Configuration.h                    | 6 ++++++
 151 files changed, 884 insertions(+), 10 deletions(-)

diff --git a/Marlin/Configuration.h b/Marlin/Configuration.h
index 90351c6025..e41bae29bb 100644
--- a/Marlin/Configuration.h
+++ b/Marlin/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/Marlin/src/core/utility.cpp b/Marlin/src/core/utility.cpp
index 189a505cc3..7826f5554b 100644
--- a/Marlin/src/core/utility.cpp
+++ b/Marlin/src/core/utility.cpp
@@ -59,6 +59,8 @@ void safe_delay(millis_t ms) {
     SERIAL_ECHOLNPGM("Probe: "
       #if ENABLED(PROBE_MANUALLY)
         "PROBE_MANUALLY"
+      #elif ENABLED(NOZZLE_AS_PROBE)
+        "NOZZLE_AS_PROBE"
       #elif ENABLED(FIX_MOUNTED_PROBE)
         "FIX_MOUNTED_PROBE"
       #elif ENABLED(BLTOUCH)
diff --git a/Marlin/src/gcode/bedlevel/abl/G29.cpp b/Marlin/src/gcode/bedlevel/abl/G29.cpp
index 41e5fce4d2..4503a51cb7 100644
--- a/Marlin/src/gcode/bedlevel/abl/G29.cpp
+++ b/Marlin/src/gcode/bedlevel/abl/G29.cpp
@@ -403,13 +403,14 @@ G29_TYPE GcodeSuite::G29() {
       }
       else {
         probe_position_lf.set(
-          parser.seenval('L') ? (int)RAW_X_POSITION(parser.value_linear_units()) : _MAX(X_CENTER - (X_BED_SIZE) / 2,      x_min),
-          parser.seenval('F') ? (int)RAW_Y_POSITION(parser.value_linear_units()) : _MAX(Y_CENTER - (Y_BED_SIZE) / 2,      y_min)
+          parser.seenval('L') ? (int)RAW_X_POSITION(parser.value_linear_units()) : (_MAX(x_min, X_CENTER - (X_BED_SIZE) / 2)      + MIN_PROBE_EDGE_LEFT),
+          parser.seenval('F') ? (int)RAW_Y_POSITION(parser.value_linear_units()) : (_MAX(y_min, Y_CENTER - (Y_BED_SIZE) / 2)      + MIN_PROBE_EDGE_FRONT)
         );
         probe_position_rb.set(
-          parser.seenval('R') ? (int)RAW_X_POSITION(parser.value_linear_units()) : _MIN(probe_position_lf.x + X_BED_SIZE, x_max),
-          parser.seenval('B') ? (int)RAW_Y_POSITION(parser.value_linear_units()) : _MIN(probe_position_lf.y + Y_BED_SIZE, y_max)
+          parser.seenval('R') ? (int)RAW_X_POSITION(parser.value_linear_units()) : (_MIN(x_max, probe_position_lf.x + X_BED_SIZE) - MIN_PROBE_EDGE_RIGHT),
+          parser.seenval('B') ? (int)RAW_Y_POSITION(parser.value_linear_units()) : (_MIN(y_max, probe_position_lf.y + Y_BED_SIZE) - MIN_PROBE_EDGE_BACK)
         );
+        SERIAL_ECHOLN("Set Trail 1");
       }
 
       if (
diff --git a/Marlin/src/inc/Conditionals_LCD.h b/Marlin/src/inc/Conditionals_LCD.h
index 713de59c62..a471e3d8b1 100644
--- a/Marlin/src/inc/Conditionals_LCD.h
+++ b/Marlin/src/inc/Conditionals_LCD.h
@@ -496,7 +496,7 @@
 /**
  * Set flags for enabled probes
  */
-#define HAS_BED_PROBE (HAS_Z_SERVO_PROBE || ANY(FIX_MOUNTED_PROBE, TOUCH_MI_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, SOLENOID_PROBE, SENSORLESS_PROBING, RACK_AND_PINION_PROBE))
+#define HAS_BED_PROBE (HAS_Z_SERVO_PROBE || ANY(FIX_MOUNTED_PROBE, NOZZLE_AS_PROBE, TOUCH_MI_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, SOLENOID_PROBE, SENSORLESS_PROBING, RACK_AND_PINION_PROBE))
 #define PROBE_SELECTED (HAS_BED_PROBE || EITHER(PROBE_MANUALLY, MESH_BED_LEVELING))
 
 #if HAS_BED_PROBE
diff --git a/Marlin/src/inc/Conditionals_post.h b/Marlin/src/inc/Conditionals_post.h
index eb9692ab62..9c1393578c 100644
--- a/Marlin/src/inc/Conditionals_post.h
+++ b/Marlin/src/inc/Conditionals_post.h
@@ -1483,6 +1483,10 @@
   #undef MIN_PROBE_EDGE_RIGHT
   #undef MIN_PROBE_EDGE_FRONT
   #undef MIN_PROBE_EDGE_BACK
+  #define MIN_PROBE_EDGE_LEFT 0
+  #define MIN_PROBE_EDGE_RIGHT 0
+  #define MIN_PROBE_EDGE_FRONT 0
+  #define MIN_PROBE_EDGE_BACK 0
 #else
   #ifndef MIN_PROBE_EDGE_LEFT
     #define MIN_PROBE_EDGE_LEFT MIN_PROBE_EDGE
diff --git a/Marlin/src/module/probe.cpp b/Marlin/src/module/probe.cpp
index 36789251fd..10e9dd5fff 100644
--- a/Marlin/src/module/probe.cpp
+++ b/Marlin/src/module/probe.cpp
@@ -358,7 +358,7 @@ bool set_probe_deployed(const bool deploy) {
   // Make room for probe to deploy (or stow)
   // Fix-mounted probe should only raise for deploy
   // unless PAUSE_BEFORE_DEPLOY_STOW is enabled
-  #if ENABLED(FIX_MOUNTED_PROBE) && DISABLED(PAUSE_BEFORE_DEPLOY_STOW)
+  #if EITHER(FIX_MOUNTED_PROBE, NOZZLE_AS_PROBE) && DISABLED(PAUSE_BEFORE_DEPLOY_STOW)
     const bool deploy_stow_condition = deploy;
   #else
     constexpr bool deploy_stow_condition = true;
diff --git a/Marlin/src/module/probe.h b/Marlin/src/module/probe.h
index 928eb43ab5..9345787d44 100644
--- a/Marlin/src/module/probe.h
+++ b/Marlin/src/module/probe.h
@@ -85,6 +85,8 @@
     return (
       #if IS_KINEMATIC
         (X_CENTER) - probe_radius()
+      #elif ENABLED(NOZZLE_AS_PROBE)
+        _MAX(MIN_PROBE_EDGE_LEFT, X_MIN_POS)
       #else
         _MAX((X_MIN_BED) + (MIN_PROBE_EDGE_LEFT), (X_MIN_POS) + probe_offset.x)
       #endif
@@ -94,6 +96,8 @@
     return (
       #if IS_KINEMATIC
         (X_CENTER) + probe_radius()
+      #elif ENABLED(NOZZLE_AS_PROBE)
+        _MAX(MIN_PROBE_EDGE_RIGHT, X_MAX_POS)
       #else
         _MIN((X_MAX_BED) - (MIN_PROBE_EDGE_RIGHT), (X_MAX_POS) + probe_offset.x)
       #endif
@@ -103,6 +107,8 @@
     return (
       #if IS_KINEMATIC
         (Y_CENTER) - probe_radius()
+      #elif ENABLED(NOZZLE_AS_PROBE)
+        _MIN(MIN_PROBE_EDGE_FRONT, Y_MIN_POS)
       #else
         _MAX((Y_MIN_BED) + (MIN_PROBE_EDGE_FRONT), (Y_MIN_POS) + probe_offset.y)
       #endif
@@ -112,6 +118,8 @@
     return (
       #if IS_KINEMATIC
         (Y_CENTER) + probe_radius()
+      #elif ENABLED(NOZZLE_AS_PROBE)
+        _MAX(MIN_PROBE_EDGE_BACK, Y_MAX_POS)
       #else
         _MIN((Y_MAX_BED) - (MIN_PROBE_EDGE_BACK), (Y_MAX_POS) + probe_offset.y)
       #endif
diff --git a/buildroot/share/tests/LPC1768-tests b/buildroot/share/tests/LPC1768-tests
index 327fa37e48..881e0534ee 100755
--- a/buildroot/share/tests/LPC1768-tests
+++ b/buildroot/share/tests/LPC1768-tests
@@ -39,7 +39,7 @@ opt_set TEMP_SENSOR_1 -1
 opt_set TEMP_SENSOR_BED 5
 opt_enable REPRAP_DISCOUNT_FULL_GRAPHIC_SMART_CONTROLLER SDSUPPORT ADAPTIVE_FAN_SLOWING NO_FAN_SLOWING_IN_PID_TUNING \
            FILAMENT_WIDTH_SENSOR FILAMENT_LCD_DISPLAY PID_EXTRUSION_SCALING \
-           FIX_MOUNTED_PROBE AUTO_BED_LEVELING_BILINEAR G29_RETRY_AND_RECOVER Z_MIN_PROBE_REPEATABILITY_TEST DEBUG_LEVELING_FEATURE \
+           NOZZLE_AS_PROBE AUTO_BED_LEVELING_BILINEAR G29_RETRY_AND_RECOVER Z_MIN_PROBE_REPEATABILITY_TEST DEBUG_LEVELING_FEATURE \
            BABYSTEPPING BABYSTEP_XY BABYSTEP_ZPROBE_OFFSET BABYSTEP_ZPROBE_GFX_OVERLAY \
            PRINTCOUNTER NOZZLE_PARK_FEATURE NOZZLE_CLEAN_FEATURE SLOW_PWM_HEATERS PIDTEMPBED EEPROM_SETTINGS INCH_MODE_SUPPORT TEMPERATURE_UNITS_SUPPORT \
            Z_SAFE_HOMING ADVANCED_PAUSE_FEATURE PARK_HEAD_ON_PAUSE \
diff --git a/config/default/Configuration.h b/config/default/Configuration.h
index 90351c6025..e41bae29bb 100644
--- a/config/default/Configuration.h
+++ b/config/default/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/3DFabXYZ/Migbot/Configuration.h b/config/examples/3DFabXYZ/Migbot/Configuration.h
index dc1ca1216b..54054be5a5 100644
--- a/config/examples/3DFabXYZ/Migbot/Configuration.h
+++ b/config/examples/3DFabXYZ/Migbot/Configuration.h
@@ -862,6 +862,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/ADIMLab/Gantry v1/Configuration.h b/config/examples/ADIMLab/Gantry v1/Configuration.h
index fc4e8bb580..ca1196d4a2 100644
--- a/config/examples/ADIMLab/Gantry v1/Configuration.h	
+++ b/config/examples/ADIMLab/Gantry v1/Configuration.h	
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/ADIMLab/Gantry v2/Configuration.h b/config/examples/ADIMLab/Gantry v2/Configuration.h
index e9c1e9e238..ff7426793d 100644
--- a/config/examples/ADIMLab/Gantry v2/Configuration.h	
+++ b/config/examples/ADIMLab/Gantry v2/Configuration.h	
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/AlephObjects/TAZ4/Configuration.h b/config/examples/AlephObjects/TAZ4/Configuration.h
index 998ec1791d..03cf1366d0 100644
--- a/config/examples/AlephObjects/TAZ4/Configuration.h
+++ b/config/examples/AlephObjects/TAZ4/Configuration.h
@@ -875,6 +875,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Alfawise/U20-bltouch/Configuration.h b/config/examples/Alfawise/U20-bltouch/Configuration.h
index 9572d65f47..973c199c51 100644
--- a/config/examples/Alfawise/U20-bltouch/Configuration.h
+++ b/config/examples/Alfawise/U20-bltouch/Configuration.h
@@ -918,6 +918,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Alfawise/U20/Configuration.h b/config/examples/Alfawise/U20/Configuration.h
index e74c34d0a6..90aa931ba8 100644
--- a/config/examples/Alfawise/U20/Configuration.h
+++ b/config/examples/Alfawise/U20/Configuration.h
@@ -918,6 +918,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/AliExpress/CL-260/Configuration.h b/config/examples/AliExpress/CL-260/Configuration.h
index 395359059a..4d85f93949 100644
--- a/config/examples/AliExpress/CL-260/Configuration.h
+++ b/config/examples/AliExpress/CL-260/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/AliExpress/UM2pExt/Configuration.h b/config/examples/AliExpress/UM2pExt/Configuration.h
index e90af33464..8c2f8174f2 100644
--- a/config/examples/AliExpress/UM2pExt/Configuration.h
+++ b/config/examples/AliExpress/UM2pExt/Configuration.h
@@ -866,6 +866,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Anet/A2/Configuration.h b/config/examples/Anet/A2/Configuration.h
index 9e7d68e345..4f87aa4db5 100644
--- a/config/examples/Anet/A2/Configuration.h
+++ b/config/examples/Anet/A2/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Anet/A2plus/Configuration.h b/config/examples/Anet/A2plus/Configuration.h
index 5feefe6553..05a08af759 100644
--- a/config/examples/Anet/A2plus/Configuration.h
+++ b/config/examples/Anet/A2plus/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Anet/A6/Configuration.h b/config/examples/Anet/A6/Configuration.h
index fdeb7e6388..57296bf117 100644
--- a/config/examples/Anet/A6/Configuration.h
+++ b/config/examples/Anet/A6/Configuration.h
@@ -896,6 +896,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Anet/A8/Configuration.h b/config/examples/Anet/A8/Configuration.h
index 0405631bc4..a6098e47f2 100644
--- a/config/examples/Anet/A8/Configuration.h
+++ b/config/examples/Anet/A8/Configuration.h
@@ -868,6 +868,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Anet/A8plus/Configuration.h b/config/examples/Anet/A8plus/Configuration.h
index 47383d785b..d88ef28e14 100644
--- a/config/examples/Anet/A8plus/Configuration.h
+++ b/config/examples/Anet/A8plus/Configuration.h
@@ -866,6 +866,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Anet/E16/Configuration.h b/config/examples/Anet/E16/Configuration.h
index 61ea635f4f..c6ffb05808 100644
--- a/config/examples/Anet/E16/Configuration.h
+++ b/config/examples/Anet/E16/Configuration.h
@@ -867,6 +867,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/AnyCubic/i3/Configuration.h b/config/examples/AnyCubic/i3/Configuration.h
index 52672551e7..3e14bc221b 100644
--- a/config/examples/AnyCubic/i3/Configuration.h
+++ b/config/examples/AnyCubic/i3/Configuration.h
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/ArmEd/Configuration.h b/config/examples/ArmEd/Configuration.h
index eabab5039b..f539452768 100644
--- a/config/examples/ArmEd/Configuration.h
+++ b/config/examples/ArmEd/Configuration.h
@@ -856,6 +856,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Azteeg/X5GT/Configuration.h b/config/examples/Azteeg/X5GT/Configuration.h
index 75cd805e40..9730e1e2f6 100644
--- a/config/examples/Azteeg/X5GT/Configuration.h
+++ b/config/examples/Azteeg/X5GT/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BIBO/TouchX/cyclops/Configuration.h b/config/examples/BIBO/TouchX/cyclops/Configuration.h
index 3e0d79eb10..10dc544f01 100644
--- a/config/examples/BIBO/TouchX/cyclops/Configuration.h
+++ b/config/examples/BIBO/TouchX/cyclops/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BIBO/TouchX/default/Configuration.h b/config/examples/BIBO/TouchX/default/Configuration.h
index 0193b46c3b..14fbb22722 100644
--- a/config/examples/BIBO/TouchX/default/Configuration.h
+++ b/config/examples/BIBO/TouchX/default/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BQ/Hephestos/Configuration.h b/config/examples/BQ/Hephestos/Configuration.h
index ad322cf107..d907a758bb 100644
--- a/config/examples/BQ/Hephestos/Configuration.h
+++ b/config/examples/BQ/Hephestos/Configuration.h
@@ -843,6 +843,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BQ/Hephestos_2/Configuration.h b/config/examples/BQ/Hephestos_2/Configuration.h
index 5844ba1cec..5865eee9bd 100644
--- a/config/examples/BQ/Hephestos_2/Configuration.h
+++ b/config/examples/BQ/Hephestos_2/Configuration.h
@@ -856,6 +856,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BQ/WITBOX/Configuration.h b/config/examples/BQ/WITBOX/Configuration.h
index c6bcc3946b..f42956985f 100644
--- a/config/examples/BQ/WITBOX/Configuration.h
+++ b/config/examples/BQ/WITBOX/Configuration.h
@@ -843,6 +843,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BigTreeTech/SKR Mini E3 1.0/Configuration.h b/config/examples/BigTreeTech/SKR Mini E3 1.0/Configuration.h
index bd151cc726..54973430e5 100644
--- a/config/examples/BigTreeTech/SKR Mini E3 1.0/Configuration.h	
+++ b/config/examples/BigTreeTech/SKR Mini E3 1.0/Configuration.h	
@@ -847,6 +847,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/BigTreeTech/SKR Mini E3 1.2/Configuration.h b/config/examples/BigTreeTech/SKR Mini E3 1.2/Configuration.h
index 0f0a345c4c..431f52ec55 100644
--- a/config/examples/BigTreeTech/SKR Mini E3 1.2/Configuration.h	
+++ b/config/examples/BigTreeTech/SKR Mini E3 1.2/Configuration.h	
@@ -848,6 +848,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Cartesio/Configuration.h b/config/examples/Cartesio/Configuration.h
index 18c9e6d4d7..ebd70b015b 100644
--- a/config/examples/Cartesio/Configuration.h
+++ b/config/examples/Cartesio/Configuration.h
@@ -854,6 +854,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-10/Configuration.h b/config/examples/Creality/CR-10/Configuration.h
index 8c8609f9d6..86589445f1 100644
--- a/config/examples/Creality/CR-10/Configuration.h
+++ b/config/examples/Creality/CR-10/Configuration.h
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-10S/Configuration.h b/config/examples/Creality/CR-10S/Configuration.h
index 9b6ea3f55c..6d188f4bae 100644
--- a/config/examples/Creality/CR-10S/Configuration.h
+++ b/config/examples/Creality/CR-10S/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-10_5S/Configuration.h b/config/examples/Creality/CR-10_5S/Configuration.h
index 82640dd9b9..6bde731076 100644
--- a/config/examples/Creality/CR-10_5S/Configuration.h
+++ b/config/examples/Creality/CR-10_5S/Configuration.h
@@ -856,6 +856,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-10mini/Configuration.h b/config/examples/Creality/CR-10mini/Configuration.h
index 1b40ae5762..4a9be92f49 100644
--- a/config/examples/Creality/CR-10mini/Configuration.h
+++ b/config/examples/Creality/CR-10mini/Configuration.h
@@ -874,6 +874,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-20 Pro/Configuration.h b/config/examples/Creality/CR-20 Pro/Configuration.h
index b109ebadbe..81754fe1cf 100644
--- a/config/examples/Creality/CR-20 Pro/Configuration.h	
+++ b/config/examples/Creality/CR-20 Pro/Configuration.h	
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-20/Configuration.h b/config/examples/Creality/CR-20/Configuration.h
index b62ccd6307..e92218aeed 100644
--- a/config/examples/Creality/CR-20/Configuration.h
+++ b/config/examples/Creality/CR-20/Configuration.h
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/CR-8/Configuration.h b/config/examples/Creality/CR-8/Configuration.h
index 378608a308..30da9c0064 100644
--- a/config/examples/Creality/CR-8/Configuration.h
+++ b/config/examples/Creality/CR-8/Configuration.h
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/Ender-2/Configuration.h b/config/examples/Creality/Ender-2/Configuration.h
index e6eb1fe110..7733dbde6a 100644
--- a/config/examples/Creality/Ender-2/Configuration.h
+++ b/config/examples/Creality/Ender-2/Configuration.h
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/Ender-3/Configuration.h b/config/examples/Creality/Ender-3/Configuration.h
index 7e83d8001e..b30dd1b807 100644
--- a/config/examples/Creality/Ender-3/Configuration.h
+++ b/config/examples/Creality/Ender-3/Configuration.h
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/Ender-4/Configuration.h b/config/examples/Creality/Ender-4/Configuration.h
index 1aae8ddbc2..2e59277b40 100644
--- a/config/examples/Creality/Ender-4/Configuration.h
+++ b/config/examples/Creality/Ender-4/Configuration.h
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Creality/Ender-5/Configuration.h b/config/examples/Creality/Ender-5/Configuration.h
index 58ac7c4fdb..517c4c825c 100644
--- a/config/examples/Creality/Ender-5/Configuration.h
+++ b/config/examples/Creality/Ender-5/Configuration.h
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Dagoma/Disco Ultimate/Configuration.h b/config/examples/Dagoma/Disco Ultimate/Configuration.h
index 627493c758..ac83ae9ba9 100644
--- a/config/examples/Dagoma/Disco Ultimate/Configuration.h	
+++ b/config/examples/Dagoma/Disco Ultimate/Configuration.h	
@@ -855,6 +855,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/EVNOVO (Artillery)/Sidewinder X1/Configuration.h b/config/examples/EVNOVO (Artillery)/Sidewinder X1/Configuration.h
index 2d6126b84c..9193daa2bd 100644
--- a/config/examples/EVNOVO (Artillery)/Sidewinder X1/Configuration.h	
+++ b/config/examples/EVNOVO (Artillery)/Sidewinder X1/Configuration.h	
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/EXP3D/Imprimante multifonction/Configuration.h b/config/examples/EXP3D/Imprimante multifonction/Configuration.h
index f123b03c50..b6746dc288 100644
--- a/config/examples/EXP3D/Imprimante multifonction/Configuration.h	
+++ b/config/examples/EXP3D/Imprimante multifonction/Configuration.h	
@@ -855,6 +855,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Einstart-S/Configuration.h b/config/examples/Einstart-S/Configuration.h
index ba38b5cfb4..e1245dd068 100644
--- a/config/examples/Einstart-S/Configuration.h
+++ b/config/examples/Einstart-S/Configuration.h
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/AIO_II/Configuration.h b/config/examples/FYSETC/AIO_II/Configuration.h
index 930c685c5e..d725f89597 100644
--- a/config/examples/FYSETC/AIO_II/Configuration.h
+++ b/config/examples/FYSETC/AIO_II/Configuration.h
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/Cheetah 1.2/BLTouch/Configuration.h b/config/examples/FYSETC/Cheetah 1.2/BLTouch/Configuration.h
index da9cf73475..501bf88412 100644
--- a/config/examples/FYSETC/Cheetah 1.2/BLTouch/Configuration.h	
+++ b/config/examples/FYSETC/Cheetah 1.2/BLTouch/Configuration.h	
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/Cheetah 1.2/base/Configuration.h b/config/examples/FYSETC/Cheetah 1.2/base/Configuration.h
index c5f85fcca7..d8bdebb888 100644
--- a/config/examples/FYSETC/Cheetah 1.2/base/Configuration.h	
+++ b/config/examples/FYSETC/Cheetah 1.2/base/Configuration.h	
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/Cheetah/BLTouch/Configuration.h b/config/examples/FYSETC/Cheetah/BLTouch/Configuration.h
index c5167d967e..fcc6f6c1c1 100644
--- a/config/examples/FYSETC/Cheetah/BLTouch/Configuration.h
+++ b/config/examples/FYSETC/Cheetah/BLTouch/Configuration.h
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/Cheetah/base/Configuration.h b/config/examples/FYSETC/Cheetah/base/Configuration.h
index e6aa505a7e..22d0f73a43 100644
--- a/config/examples/FYSETC/Cheetah/base/Configuration.h
+++ b/config/examples/FYSETC/Cheetah/base/Configuration.h
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/F6_13/Configuration.h b/config/examples/FYSETC/F6_13/Configuration.h
index e49069eab3..7dc08fa84b 100644
--- a/config/examples/FYSETC/F6_13/Configuration.h
+++ b/config/examples/FYSETC/F6_13/Configuration.h
@@ -857,6 +857,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FYSETC/S6/Configuration.h b/config/examples/FYSETC/S6/Configuration.h
index 66a120871e..6fbb938ebc 100644
--- a/config/examples/FYSETC/S6/Configuration.h
+++ b/config/examples/FYSETC/S6/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Felix/DUAL/Configuration.h b/config/examples/Felix/DUAL/Configuration.h
index 03d76007fe..abaca53b57 100644
--- a/config/examples/Felix/DUAL/Configuration.h
+++ b/config/examples/Felix/DUAL/Configuration.h
@@ -836,6 +836,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Felix/Single/Configuration.h b/config/examples/Felix/Single/Configuration.h
index 9b97a6365e..aadea5c3c6 100644
--- a/config/examples/Felix/Single/Configuration.h
+++ b/config/examples/Felix/Single/Configuration.h
@@ -836,6 +836,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FlashForge/CreatorPro/Configuration.h b/config/examples/FlashForge/CreatorPro/Configuration.h
index ec8fd41a28..d8b48ef8ab 100644
--- a/config/examples/FlashForge/CreatorPro/Configuration.h
+++ b/config/examples/FlashForge/CreatorPro/Configuration.h
@@ -847,6 +847,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/FolgerTech/i3-2020/Configuration.h b/config/examples/FolgerTech/i3-2020/Configuration.h
index fb142d4a5c..7d17d2c4cf 100644
--- a/config/examples/FolgerTech/i3-2020/Configuration.h
+++ b/config/examples/FolgerTech/i3-2020/Configuration.h
@@ -861,6 +861,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Formbot/Raptor/Configuration.h b/config/examples/Formbot/Raptor/Configuration.h
index 479b0ca4e4..7b76169c3c 100644
--- a/config/examples/Formbot/Raptor/Configuration.h
+++ b/config/examples/Formbot/Raptor/Configuration.h
@@ -940,6 +940,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Formbot/T_Rex_2+/Configuration.h b/config/examples/Formbot/T_Rex_2+/Configuration.h
index d4b1a95e1a..1e04fd26cc 100644
--- a/config/examples/Formbot/T_Rex_2+/Configuration.h
+++ b/config/examples/Formbot/T_Rex_2+/Configuration.h
@@ -884,6 +884,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Formbot/T_Rex_3/Configuration.h b/config/examples/Formbot/T_Rex_3/Configuration.h
index aa880f5ce7..271d3958ac 100644
--- a/config/examples/Formbot/T_Rex_3/Configuration.h
+++ b/config/examples/Formbot/T_Rex_3/Configuration.h
@@ -867,6 +867,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A10/Configuration.h b/config/examples/Geeetech/A10/Configuration.h
index beb74ad6a3..22043fb3e9 100644
--- a/config/examples/Geeetech/A10/Configuration.h
+++ b/config/examples/Geeetech/A10/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A10D/Configuration.h b/config/examples/Geeetech/A10D/Configuration.h
index 4f97173ad2..934ac4b83d 100644
--- a/config/examples/Geeetech/A10D/Configuration.h
+++ b/config/examples/Geeetech/A10D/Configuration.h
@@ -837,6 +837,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A10M/Configuration.h b/config/examples/Geeetech/A10M/Configuration.h
index bf68276959..99573fd620 100644
--- a/config/examples/Geeetech/A10M/Configuration.h
+++ b/config/examples/Geeetech/A10M/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A10T/Configuration.h b/config/examples/Geeetech/A10T/Configuration.h
index 0541d024b1..b22f80bb53 100644
--- a/config/examples/Geeetech/A10T/Configuration.h
+++ b/config/examples/Geeetech/A10T/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A20/Configuration.h b/config/examples/Geeetech/A20/Configuration.h
index c41939d8ff..342994f570 100644
--- a/config/examples/Geeetech/A20/Configuration.h
+++ b/config/examples/Geeetech/A20/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A20M/Configuration.h b/config/examples/Geeetech/A20M/Configuration.h
index 6fb7a8b699..ca65f4fcbe 100644
--- a/config/examples/Geeetech/A20M/Configuration.h
+++ b/config/examples/Geeetech/A20M/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A20T/Configuration.h b/config/examples/Geeetech/A20T/Configuration.h
index 74d7e11ef2..62a4f4ef48 100644
--- a/config/examples/Geeetech/A20T/Configuration.h
+++ b/config/examples/Geeetech/A20T/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/A30/Configuration.h b/config/examples/Geeetech/A30/Configuration.h
index f0993aa0cd..81ea4e8702 100644
--- a/config/examples/Geeetech/A30/Configuration.h
+++ b/config/examples/Geeetech/A30/Configuration.h
@@ -838,6 +838,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/E180/Configuration.h b/config/examples/Geeetech/E180/Configuration.h
index 5c88c6015d..e020ccdfbb 100644
--- a/config/examples/Geeetech/E180/Configuration.h
+++ b/config/examples/Geeetech/E180/Configuration.h
@@ -839,6 +839,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/GT2560/Configuration.h b/config/examples/Geeetech/GT2560/Configuration.h
index 3f93976e2d..0ec1d6fc9b 100644
--- a/config/examples/Geeetech/GT2560/Configuration.h
+++ b/config/examples/Geeetech/GT2560/Configuration.h
@@ -870,6 +870,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/I3_Pro_X-GT2560/Configuration.h b/config/examples/Geeetech/I3_Pro_X-GT2560/Configuration.h
index a87351b334..0d39fd91a6 100644
--- a/config/examples/Geeetech/I3_Pro_X-GT2560/Configuration.h
+++ b/config/examples/Geeetech/I3_Pro_X-GT2560/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/MeCreator2/Configuration.h b/config/examples/Geeetech/MeCreator2/Configuration.h
index 03340baa8c..f944c82e32 100644
--- a/config/examples/Geeetech/MeCreator2/Configuration.h
+++ b/config/examples/Geeetech/MeCreator2/Configuration.h
@@ -862,6 +862,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/PI3A PRO/Configuration.h b/config/examples/Geeetech/PI3A PRO/Configuration.h
index cf3cddab95..bc7c82647c 100644
--- a/config/examples/Geeetech/PI3A PRO/Configuration.h	
+++ b/config/examples/Geeetech/PI3A PRO/Configuration.h	
@@ -876,6 +876,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/Prusa i3 Pro B/bltouch/Configuration.h b/config/examples/Geeetech/Prusa i3 Pro B/bltouch/Configuration.h
index f34e66b2b5..3c53510e93 100644
--- a/config/examples/Geeetech/Prusa i3 Pro B/bltouch/Configuration.h	
+++ b/config/examples/Geeetech/Prusa i3 Pro B/bltouch/Configuration.h	
@@ -876,6 +876,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/Prusa i3 Pro B/noprobe/Configuration.h b/config/examples/Geeetech/Prusa i3 Pro B/noprobe/Configuration.h
index 1e484f19ad..9c955f3d49 100644
--- a/config/examples/Geeetech/Prusa i3 Pro B/noprobe/Configuration.h	
+++ b/config/examples/Geeetech/Prusa i3 Pro B/noprobe/Configuration.h	
@@ -875,6 +875,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/Prusa i3 Pro C/Configuration.h b/config/examples/Geeetech/Prusa i3 Pro C/Configuration.h
index 9903bfe7fb..5d0ed7e3b3 100644
--- a/config/examples/Geeetech/Prusa i3 Pro C/Configuration.h	
+++ b/config/examples/Geeetech/Prusa i3 Pro C/Configuration.h	
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Geeetech/Prusa i3 Pro W/Configuration.h b/config/examples/Geeetech/Prusa i3 Pro W/Configuration.h
index 3ea78344fc..9fd9cb1aeb 100644
--- a/config/examples/Geeetech/Prusa i3 Pro W/Configuration.h	
+++ b/config/examples/Geeetech/Prusa i3 Pro W/Configuration.h	
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/HMS434/Configuration.h b/config/examples/HMS434/Configuration.h
index 46425ce1b6..675144aabb 100644
--- a/config/examples/HMS434/Configuration.h
+++ b/config/examples/HMS434/Configuration.h
@@ -844,6 +844,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Infitary/i3-M508/Configuration.h b/config/examples/Infitary/i3-M508/Configuration.h
index 95a0427940..fd631d1766 100644
--- a/config/examples/Infitary/i3-M508/Configuration.h
+++ b/config/examples/Infitary/i3-M508/Configuration.h
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/JGAurora/A1/Configuration.h b/config/examples/JGAurora/A1/Configuration.h
index f0feb6aa23..d75903b33b 100644
--- a/config/examples/JGAurora/A1/Configuration.h
+++ b/config/examples/JGAurora/A1/Configuration.h
@@ -862,6 +862,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/JGAurora/A5/Configuration.h b/config/examples/JGAurora/A5/Configuration.h
index ae77da245a..39480ec578 100644
--- a/config/examples/JGAurora/A5/Configuration.h
+++ b/config/examples/JGAurora/A5/Configuration.h
@@ -867,6 +867,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/JGAurora/A5S/Configuration.h b/config/examples/JGAurora/A5S/Configuration.h
index 0328efb6f7..0539ced6b1 100644
--- a/config/examples/JGAurora/A5S/Configuration.h
+++ b/config/examples/JGAurora/A5S/Configuration.h
@@ -862,6 +862,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/MakerParts/Configuration.h b/config/examples/MakerParts/Configuration.h
index 21c6181f24..f9f771489b 100644
--- a/config/examples/MakerParts/Configuration.h
+++ b/config/examples/MakerParts/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Malyan/M150/Configuration.h b/config/examples/Malyan/M150/Configuration.h
index 7ba61e8ad3..1844962567 100644
--- a/config/examples/Malyan/M150/Configuration.h
+++ b/config/examples/Malyan/M150/Configuration.h
@@ -875,6 +875,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Malyan/M200/Configuration.h b/config/examples/Malyan/M200/Configuration.h
index f08c3ed0b1..7b33b8831f 100644
--- a/config/examples/Malyan/M200/Configuration.h
+++ b/config/examples/Malyan/M200/Configuration.h
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Micromake/C1/basic/Configuration.h b/config/examples/Micromake/C1/basic/Configuration.h
index 73db7dcf37..e805a3d909 100644
--- a/config/examples/Micromake/C1/basic/Configuration.h
+++ b/config/examples/Micromake/C1/basic/Configuration.h
@@ -859,6 +859,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Micromake/C1/enhanced/Configuration.h b/config/examples/Micromake/C1/enhanced/Configuration.h
index c00b49ee79..cf10883293 100644
--- a/config/examples/Micromake/C1/enhanced/Configuration.h
+++ b/config/examples/Micromake/C1/enhanced/Configuration.h
@@ -859,6 +859,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Mks/Robin/Configuration.h b/config/examples/Mks/Robin/Configuration.h
index c50fb752bb..cafdcc977b 100644
--- a/config/examples/Mks/Robin/Configuration.h
+++ b/config/examples/Mks/Robin/Configuration.h
@@ -856,6 +856,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Mks/Robin_Lite3/Configuration.h b/config/examples/Mks/Robin_Lite3/Configuration.h
index 3336e4cb76..6bb626809a 100644
--- a/config/examples/Mks/Robin_Lite3/Configuration.h
+++ b/config/examples/Mks/Robin_Lite3/Configuration.h
@@ -862,6 +862,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Mks/Robin_Pro/Configuration.h b/config/examples/Mks/Robin_Pro/Configuration.h
index 526105efef..6b9895a241 100644
--- a/config/examples/Mks/Robin_Pro/Configuration.h
+++ b/config/examples/Mks/Robin_Pro/Configuration.h
@@ -861,6 +861,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Mks/Sbase/Configuration.h b/config/examples/Mks/Sbase/Configuration.h
index afb0e09331..e98821c769 100644
--- a/config/examples/Mks/Sbase/Configuration.h
+++ b/config/examples/Mks/Sbase/Configuration.h
@@ -854,6 +854,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Modix/Big60/Configuration.h b/config/examples/Modix/Big60/Configuration.h
index 6e0f6180f6..82012b2778 100644
--- a/config/examples/Modix/Big60/Configuration.h
+++ b/config/examples/Modix/Big60/Configuration.h
@@ -854,6 +854,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Printrbot/PrintrboardG2/Configuration.h b/config/examples/Printrbot/PrintrboardG2/Configuration.h
index ce05b9562e..41585db1e7 100644
--- a/config/examples/Printrbot/PrintrboardG2/Configuration.h
+++ b/config/examples/Printrbot/PrintrboardG2/Configuration.h
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/RapideLite/RL200/Configuration.h b/config/examples/RapideLite/RL200/Configuration.h
index 7cd96dc72c..10e8e08b38 100644
--- a/config/examples/RapideLite/RL200/Configuration.h
+++ b/config/examples/RapideLite/RL200/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Renkforce/RF100/Configuration.h b/config/examples/Renkforce/RF100/Configuration.h
index 2bfa7cada8..59525cb6ef 100644
--- a/config/examples/Renkforce/RF100/Configuration.h
+++ b/config/examples/Renkforce/RF100/Configuration.h
@@ -863,6 +863,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Renkforce/RF100XL/Configuration.h b/config/examples/Renkforce/RF100XL/Configuration.h
index a31aa40782..b12d288a58 100644
--- a/config/examples/Renkforce/RF100XL/Configuration.h
+++ b/config/examples/Renkforce/RF100XL/Configuration.h
@@ -863,6 +863,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Renkforce/RF100v2/Configuration.h b/config/examples/Renkforce/RF100v2/Configuration.h
index 3f184b87d9..e53e7a6366 100644
--- a/config/examples/Renkforce/RF100v2/Configuration.h
+++ b/config/examples/Renkforce/RF100v2/Configuration.h
@@ -863,6 +863,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/RepRapPro/Huxley/Configuration.h b/config/examples/RepRapPro/Huxley/Configuration.h
index 2cb1b75b4d..ab0923ed5e 100644
--- a/config/examples/RepRapPro/Huxley/Configuration.h
+++ b/config/examples/RepRapPro/Huxley/Configuration.h
@@ -895,6 +895,12 @@ Black rubber belt(MXL), 18 - tooth aluminium pulley : 87.489 step per mm (Huxley
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/RepRapWorld/Megatronics/Configuration.h b/config/examples/RepRapWorld/Megatronics/Configuration.h
index 25bcd99402..62e0980fa1 100644
--- a/config/examples/RepRapWorld/Megatronics/Configuration.h
+++ b/config/examples/RepRapWorld/Megatronics/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/RigidBot/Configuration.h b/config/examples/RigidBot/Configuration.h
index 44a991fa34..0eb2874e6f 100644
--- a/config/examples/RigidBot/Configuration.h
+++ b/config/examples/RigidBot/Configuration.h
@@ -853,6 +853,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/SCARA/MP_SCARA/Configuration.h b/config/examples/SCARA/MP_SCARA/Configuration.h
index d8479c8ffb..1b9cec18f8 100644
--- a/config/examples/SCARA/MP_SCARA/Configuration.h
+++ b/config/examples/SCARA/MP_SCARA/Configuration.h
@@ -876,6 +876,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/SCARA/Morgan/Configuration.h b/config/examples/SCARA/Morgan/Configuration.h
index 62d76b8850..39d319a142 100644
--- a/config/examples/SCARA/Morgan/Configuration.h
+++ b/config/examples/SCARA/Morgan/Configuration.h
@@ -877,6 +877,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/STM32/Black_STM32F407VET6/Configuration.h b/config/examples/STM32/Black_STM32F407VET6/Configuration.h
index 920567e4eb..b0810f7447 100644
--- a/config/examples/STM32/Black_STM32F407VET6/Configuration.h
+++ b/config/examples/STM32/Black_STM32F407VET6/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/STM32/STM32F103RE/Configuration.h b/config/examples/STM32/STM32F103RE/Configuration.h
index 55f1ef3803..66b1429a35 100644
--- a/config/examples/STM32/STM32F103RE/Configuration.h
+++ b/config/examples/STM32/STM32F103RE/Configuration.h
@@ -857,6 +857,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/STM32/STM32F4/Configuration.h b/config/examples/STM32/STM32F4/Configuration.h
index 9e51d930ea..71ab97a324 100644
--- a/config/examples/STM32/STM32F4/Configuration.h
+++ b/config/examples/STM32/STM32F4/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/STM32/stm32f103ret6/Configuration.h b/config/examples/STM32/stm32f103ret6/Configuration.h
index 1ec5d3c1f6..fcdab6c654 100644
--- a/config/examples/STM32/stm32f103ret6/Configuration.h
+++ b/config/examples/STM32/stm32f103ret6/Configuration.h
@@ -857,6 +857,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Sanguinololu/Configuration.h b/config/examples/Sanguinololu/Configuration.h
index f40afdb94e..353faeb5aa 100644
--- a/config/examples/Sanguinololu/Configuration.h
+++ b/config/examples/Sanguinololu/Configuration.h
@@ -886,6 +886,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tevo/Michelangelo/Configuration.h b/config/examples/Tevo/Michelangelo/Configuration.h
index dc0e913c9e..fd82cb9d2e 100644
--- a/config/examples/Tevo/Michelangelo/Configuration.h
+++ b/config/examples/Tevo/Michelangelo/Configuration.h
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tevo/Tarantula Pro/Configuration.h b/config/examples/Tevo/Tarantula Pro/Configuration.h
index 998a127688..e136ca3af8 100644
--- a/config/examples/Tevo/Tarantula Pro/Configuration.h	
+++ b/config/examples/Tevo/Tarantula Pro/Configuration.h	
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tevo/Tornado/V1 (MKS Base)/Configuration.h b/config/examples/Tevo/Tornado/V1 (MKS Base)/Configuration.h
index f0ecafa2ad..18440fdf8a 100644
--- a/config/examples/Tevo/Tornado/V1 (MKS Base)/Configuration.h	
+++ b/config/examples/Tevo/Tornado/V1 (MKS Base)/Configuration.h	
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tevo/Tornado/V2 (MKS GEN-L)/Configuration.h b/config/examples/Tevo/Tornado/V2 (MKS GEN-L)/Configuration.h
index c2e13fd6b6..0f7fd97134 100644
--- a/config/examples/Tevo/Tornado/V2 (MKS GEN-L)/Configuration.h	
+++ b/config/examples/Tevo/Tornado/V2 (MKS GEN-L)/Configuration.h	
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/TheBorg/Configuration.h b/config/examples/TheBorg/Configuration.h
index 44213aeb5e..0a192c0e87 100644
--- a/config/examples/TheBorg/Configuration.h
+++ b/config/examples/TheBorg/Configuration.h
@@ -855,6 +855,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/TinyBoy2/Configuration.h b/config/examples/TinyBoy2/Configuration.h
index 4d5d658005..72ace63606 100644
--- a/config/examples/TinyBoy2/Configuration.h
+++ b/config/examples/TinyBoy2/Configuration.h
@@ -906,6 +906,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tronxy/X1/Configuration.h b/config/examples/Tronxy/X1/Configuration.h
index 17e59c192e..9ce7ae4438 100644
--- a/config/examples/Tronxy/X1/Configuration.h
+++ b/config/examples/Tronxy/X1/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tronxy/X3A/Configuration.h b/config/examples/Tronxy/X3A/Configuration.h
index 0c6691df98..c3302b0bcc 100644
--- a/config/examples/Tronxy/X3A/Configuration.h
+++ b/config/examples/Tronxy/X3A/Configuration.h
@@ -855,6 +855,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tronxy/X5S-2E/Configuration.h b/config/examples/Tronxy/X5S-2E/Configuration.h
index a570f8e92f..e7cf88338b 100644
--- a/config/examples/Tronxy/X5S-2E/Configuration.h
+++ b/config/examples/Tronxy/X5S-2E/Configuration.h
@@ -876,6 +876,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tronxy/X5S/Configuration.h b/config/examples/Tronxy/X5S/Configuration.h
index 550928f271..5a5496fc02 100644
--- a/config/examples/Tronxy/X5S/Configuration.h
+++ b/config/examples/Tronxy/X5S/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Tronxy/XY100/Configuration.h b/config/examples/Tronxy/XY100/Configuration.h
index a9945cedf3..80f61f2a3c 100644
--- a/config/examples/Tronxy/XY100/Configuration.h
+++ b/config/examples/Tronxy/XY100/Configuration.h
@@ -866,6 +866,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/UltiMachine/Archim1/Configuration.h b/config/examples/UltiMachine/Archim1/Configuration.h
index f8c507afcc..488d8713b0 100644
--- a/config/examples/UltiMachine/Archim1/Configuration.h
+++ b/config/examples/UltiMachine/Archim1/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/UltiMachine/Archim2/Configuration.h b/config/examples/UltiMachine/Archim2/Configuration.h
index 0e4beead79..4e8e46d409 100644
--- a/config/examples/UltiMachine/Archim2/Configuration.h
+++ b/config/examples/UltiMachine/Archim2/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/VORONDesign/Configuration.h b/config/examples/VORONDesign/Configuration.h
index 6e43183145..a2c424a091 100644
--- a/config/examples/VORONDesign/Configuration.h
+++ b/config/examples/VORONDesign/Configuration.h
@@ -864,6 +864,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Velleman/K8200/Configuration.h b/config/examples/Velleman/K8200/Configuration.h
index 2c84aed21e..1fc123a097 100644
--- a/config/examples/Velleman/K8200/Configuration.h
+++ b/config/examples/Velleman/K8200/Configuration.h
@@ -884,6 +884,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Velleman/K8400/Dual-head/Configuration.h b/config/examples/Velleman/K8400/Dual-head/Configuration.h
index 3fcb58e01a..90c73e6a58 100644
--- a/config/examples/Velleman/K8400/Dual-head/Configuration.h
+++ b/config/examples/Velleman/K8400/Dual-head/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Velleman/K8400/Single-head/Configuration.h b/config/examples/Velleman/K8400/Single-head/Configuration.h
index fd59fa79c5..d93773dcd3 100644
--- a/config/examples/Velleman/K8400/Single-head/Configuration.h
+++ b/config/examples/Velleman/K8400/Single-head/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/WASP/PowerWASP/Configuration.h b/config/examples/WASP/PowerWASP/Configuration.h
index fd418fa19a..6c33f321ed 100644
--- a/config/examples/WASP/PowerWASP/Configuration.h
+++ b/config/examples/WASP/PowerWASP/Configuration.h
@@ -874,6 +874,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Wanhao/Duplicator 6/Configuration.h b/config/examples/Wanhao/Duplicator 6/Configuration.h
index cdb0228a71..ce6f61d543 100644
--- a/config/examples/Wanhao/Duplicator 6/Configuration.h	
+++ b/config/examples/Wanhao/Duplicator 6/Configuration.h	
@@ -865,6 +865,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Wanhao/Duplicator i3 2.1/Configuration.h b/config/examples/Wanhao/Duplicator i3 2.1/Configuration.h
index d92c740240..b5c20b83d6 100644
--- a/config/examples/Wanhao/Duplicator i3 2.1/Configuration.h	
+++ b/config/examples/Wanhao/Duplicator i3 2.1/Configuration.h	
@@ -866,6 +866,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/Wanhao/Duplicator i3 Mini/Configuration.h b/config/examples/Wanhao/Duplicator i3 Mini/Configuration.h
index 2b0964ff4e..6dcd80acbf 100755
--- a/config/examples/Wanhao/Duplicator i3 Mini/Configuration.h	
+++ b/config/examples/Wanhao/Duplicator i3 Mini/Configuration.h	
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/adafruit/ST7565/Configuration.h b/config/examples/adafruit/ST7565/Configuration.h
index 3fa78f419b..a95468960a 100644
--- a/config/examples/adafruit/ST7565/Configuration.h
+++ b/config/examples/adafruit/ST7565/Configuration.h
@@ -855,6 +855,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/Dreammaker/Overlord/Configuration.h b/config/examples/delta/Dreammaker/Overlord/Configuration.h
index 2dfd8f636d..f6d8287894 100644
--- a/config/examples/delta/Dreammaker/Overlord/Configuration.h
+++ b/config/examples/delta/Dreammaker/Overlord/Configuration.h
@@ -933,6 +933,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/Dreammaker/Overlord_Pro/Configuration.h b/config/examples/delta/Dreammaker/Overlord_Pro/Configuration.h
index 3684aa5034..94979f58f7 100644
--- a/config/examples/delta/Dreammaker/Overlord_Pro/Configuration.h
+++ b/config/examples/delta/Dreammaker/Overlord_Pro/Configuration.h
@@ -945,6 +945,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/FLSUN/QQ-S/Configuration.h b/config/examples/delta/FLSUN/QQ-S/Configuration.h
index a43e38620a..09ba19da59 100644
--- a/config/examples/delta/FLSUN/QQ-S/Configuration.h
+++ b/config/examples/delta/FLSUN/QQ-S/Configuration.h
@@ -935,6 +935,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/FLSUN/auto_calibrate/Configuration.h b/config/examples/delta/FLSUN/auto_calibrate/Configuration.h
index 125f2d0b66..b842f8ee5b 100644
--- a/config/examples/delta/FLSUN/auto_calibrate/Configuration.h
+++ b/config/examples/delta/FLSUN/auto_calibrate/Configuration.h
@@ -935,6 +935,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/FLSUN/kossel/Configuration.h b/config/examples/delta/FLSUN/kossel/Configuration.h
index b4c8dfc9b6..a4c71e6113 100644
--- a/config/examples/delta/FLSUN/kossel/Configuration.h
+++ b/config/examples/delta/FLSUN/kossel/Configuration.h
@@ -935,6 +935,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/FLSUN/kossel_mini/Configuration.h b/config/examples/delta/FLSUN/kossel_mini/Configuration.h
index 8f324f5736..0db33ff999 100644
--- a/config/examples/delta/FLSUN/kossel_mini/Configuration.h
+++ b/config/examples/delta/FLSUN/kossel_mini/Configuration.h
@@ -935,6 +935,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/Geeetech/Rostock 301/Configuration.h b/config/examples/delta/Geeetech/Rostock 301/Configuration.h
index 17003b4cc3..d42e985459 100644
--- a/config/examples/delta/Geeetech/Rostock 301/Configuration.h	
+++ b/config/examples/delta/Geeetech/Rostock 301/Configuration.h	
@@ -925,6 +925,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/Hatchbox_Alpha/Configuration.h b/config/examples/delta/Hatchbox_Alpha/Configuration.h
index a93be77f78..65e4fcb08e 100644
--- a/config/examples/delta/Hatchbox_Alpha/Configuration.h
+++ b/config/examples/delta/Hatchbox_Alpha/Configuration.h
@@ -940,6 +940,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/MKS/SBASE/Configuration.h b/config/examples/delta/MKS/SBASE/Configuration.h
index bd29cb0e5b..231f6e5e75 100644
--- a/config/examples/delta/MKS/SBASE/Configuration.h
+++ b/config/examples/delta/MKS/SBASE/Configuration.h
@@ -924,6 +924,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/Tevo Little Monster/Configuration.h b/config/examples/delta/Tevo Little Monster/Configuration.h
index 35f80f74b9..b30054c071 100644
--- a/config/examples/delta/Tevo Little Monster/Configuration.h	
+++ b/config/examples/delta/Tevo Little Monster/Configuration.h	
@@ -929,6 +929,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/generic/Configuration.h b/config/examples/delta/generic/Configuration.h
index a13d0c6306..3312cbcd7c 100644
--- a/config/examples/delta/generic/Configuration.h
+++ b/config/examples/delta/generic/Configuration.h
@@ -925,6 +925,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/kossel_mini/Configuration.h b/config/examples/delta/kossel_mini/Configuration.h
index 09d847d403..d09738f56b 100644
--- a/config/examples/delta/kossel_mini/Configuration.h
+++ b/config/examples/delta/kossel_mini/Configuration.h
@@ -925,6 +925,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/kossel_pro/Configuration.h b/config/examples/delta/kossel_pro/Configuration.h
index 37dec65d3a..20d57e571f 100644
--- a/config/examples/delta/kossel_pro/Configuration.h
+++ b/config/examples/delta/kossel_pro/Configuration.h
@@ -918,6 +918,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/delta/kossel_xl/Configuration.h b/config/examples/delta/kossel_xl/Configuration.h
index 1c5b3ae075..0ad3f64be7 100644
--- a/config/examples/delta/kossel_xl/Configuration.h
+++ b/config/examples/delta/kossel_xl/Configuration.h
@@ -928,6 +928,12 @@
  */
 #define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/gCreate/gMax1.5+/Configuration.h b/config/examples/gCreate/gMax1.5+/Configuration.h
index 6ee459b442..05be303ecc 100644
--- a/config/examples/gCreate/gMax1.5+/Configuration.h
+++ b/config/examples/gCreate/gMax1.5+/Configuration.h
@@ -868,6 +868,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/makibox/Configuration.h b/config/examples/makibox/Configuration.h
index 0e7ba8cd58..3d4fbaa1f1 100644
--- a/config/examples/makibox/Configuration.h
+++ b/config/examples/makibox/Configuration.h
@@ -858,6 +858,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/tvrrug/Round2/Configuration.h b/config/examples/tvrrug/Round2/Configuration.h
index 6003c836ee..d0f8637c9f 100644
--- a/config/examples/tvrrug/Round2/Configuration.h
+++ b/config/examples/tvrrug/Round2/Configuration.h
@@ -850,6 +850,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/config/examples/wt150/Configuration.h b/config/examples/wt150/Configuration.h
index 45ea71464c..ac81221682 100644
--- a/config/examples/wt150/Configuration.h
+++ b/config/examples/wt150/Configuration.h
@@ -860,6 +860,12 @@
  */
 //#define FIX_MOUNTED_PROBE
 
+/**
+ * Use the nozzle as the probe, as with a conductive
+ * nozzle system or a piezo-electric smart effector.
+ */
+//#define NOZZLE_AS_PROBE
+
 /**
  * Z Servo Probe, such as an endstop switch on a rotating arm.
  */
diff --git a/Marlin/src/inc/SanityCheck.h b/Marlin/src/inc/SanityCheck.h
index bec75218cf..2b9a49ed24 100644
--- a/Marlin/src/inc/SanityCheck.h
+++ b/Marlin/src/inc/SanityCheck.h
@@ -1082,6 +1082,7 @@ static_assert(Y_MAX_LENGTH >= Y_BED_SIZE, "Movement bounds (Y_MIN_POS, Y_MAX_POS
 #if 1 < 0 \
   + ENABLED(PROBE_MANUALLY) \
   + ENABLED(FIX_MOUNTED_PROBE) \
+  + ENABLED(NOZZLE_AS_PROBE) \
   + (HAS_Z_SERVO_PROBE && DISABLED(BLTOUCH)) \
   + ENABLED(BLTOUCH) \
   + ENABLED(TOUCH_MI_PROBE) \
@@ -1090,7 +1091,7 @@ static_assert(Y_MAX_LENGTH >= Y_BED_SIZE, "Movement bounds (Y_MIN_POS, Y_MAX_POS
   + ENABLED(Z_PROBE_SLED) \
   + ENABLED(RACK_AND_PINION_PROBE) \
   + ENABLED(SENSORLESS_PROBING)
   #error "Please enable only one probe option: PROBE_MANUALLY, SENSORLESS_PROBING, BLTOUCH, FIX_MOUNTED_PROBE, TOUCH_MI_PROBE, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or Z Servo."
 #endif
 
 #if HAS_BED_PROBE
@@ -1221,11 +1222,11 @@ static_assert(Y_MAX_LENGTH >= Y_BED_SIZE, "Movement bounds (Y_MIN_POS, Y_MAX_POS
    * Require some kind of probe for bed leveling and probe testing
    */
   #if HAS_ABL_NOT_UBL && !PROBE_SELECTED
     #error "Auto Bed Leveling requires one of these: PROBE_MANUALLY, FIX_MOUNTED_PROBE, BLTOUCH, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or a Z Servo."
   #endif
 
   #if ENABLED(Z_MIN_PROBE_REPEATABILITY_TEST)
     #error "Z_MIN_PROBE_REPEATABILITY_TEST requires a probe: FIX_MOUNTED_PROBE, BLTOUCH, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or Z Servo."
   #endif
 
 #endif
@@ -1090,7 +1091,7 @@ static_assert(Y_MAX_LENGTH >= Y_BED_SIZE, "Movement bounds (Y_MIN_POS, Y_MAX_POS
   + ENABLED(RACK_AND_PINION_PROBE) \
   + ENABLED(SENSORLESS_PROBING)
-  #error "Please enable only one probe option: PROBE_MANUALLY, SENSORLESS_PROBING, BLTOUCH, FIX_MOUNTED_PROBE, TOUCH_MI_PROBE, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or Z Servo."
+  #error "Please enable only one probe option: PROBE_MANUALLY, SENSORLESS_PROBING, BLTOUCH, FIX_MOUNTED_PROBE, NOZZLE_AS_PROBE, TOUCH_MI_PROBE, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or Z Servo."
 #endif
 
@@ -1221,11 +1222,11 @@ static_assert(Y_MAX_LENGTH >= Y_BED_SIZE, "Movement bounds (Y_MIN_POS, Y_MAX_POS
    */
   #if HAS_ABL_NOT_UBL && !PROBE_SELECTED
-    #error "Auto Bed Leveling requires one of these: PROBE_MANUALLY, FIX_MOUNTED_PROBE, BLTOUCH, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or a Z Servo."
+    #error "Auto Bed Leveling requires one of these: PROBE_MANUALLY, FIX_MOUNTED_PROBE, NOZZLE_AS_PROBE, BLTOUCH, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or a Z Servo."
   #endif
 
@@ -1221,11 +1222,11 @@ static_assert(Y_MAX_LENGTH >= Y_BED_SIZE, "Movement bounds (Y_MIN_POS, Y_MAX_POS
 
   #if ENABLED(Z_MIN_PROBE_REPEATABILITY_TEST)
-    #error "Z_MIN_PROBE_REPEATABILITY_TEST requires a probe: FIX_MOUNTED_PROBE, BLTOUCH, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or Z Servo."
+    #error "Z_MIN_PROBE_REPEATABILITY_TEST requires a probe: FIX_MOUNTED_PROBE, NOZZLE_AS_PROBE, BLTOUCH, SOLENOID_PROBE, Z_PROBE_ALLEN_KEY, Z_PROBE_SLED, or Z Servo."
   #endif
 
-- 
GitLab